# coding: utf-8

"""
    RiseML API


    OpenAPI spec version: 1.1.0
    Contact: support@riseml.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ScratchEntry(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, name=None, size=None, is_dir=None):
        """
        ScratchEntry - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'size': 'int',
            'is_dir': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'size': 'size',
            'is_dir': 'is_dir'
        }

        self._name = name
        self._size = size
        self._is_dir = is_dir


    @property
    def name(self):
        """
        Gets the name of this ScratchEntry.


        :return: The name of this ScratchEntry.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ScratchEntry.


        :param name: The name of this ScratchEntry.
        :type: str
        """

        self._name = name

    @property
    def size(self):
        """
        Gets the size of this ScratchEntry.


        :return: The size of this ScratchEntry.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this ScratchEntry.


        :param size: The size of this ScratchEntry.
        :type: int
        """

        self._size = size

    @property
    def is_dir(self):
        """
        Gets the is_dir of this ScratchEntry.


        :return: The is_dir of this ScratchEntry.
        :rtype: bool
        """
        return self._is_dir

    @is_dir.setter
    def is_dir(self, is_dir):
        """
        Sets the is_dir of this ScratchEntry.


        :param is_dir: The is_dir of this ScratchEntry.
        :type: bool
        """

        self._is_dir = is_dir

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
